{ inputs, lib, pkgs, ... }:
{
  imports = [
    inputs.apple-silicon.nixosModules.default
    ./hardware-configuration.nix
  ];

  # Generic Config
  nix.settings.experimental-features = [ "nix-command" "flakes" ];
  nixpkgs.hostPlatform = lib.mkDefault "aarch64-linux";
  time.timeZone = "America/New_York";

  # Boot Loader Config
  boot.loader = {
    systemd-boot.enable = true;
    efi.canTouchEfiVariables = false;
  };

  # Networking Config
  networking = {
    firewall.enable = true;
    hostName = "mpb-nixos";
    networkmanager.enable = true;
    networkmanager.wifi.backend = "iwd";
    useDHCP = lib.mkDefault true;
    wireless.iwd.enable = true;
  };

  # Hardware Config
  hardware = {
    asahi = {
      peripheralFirmwareDirectory = ./firmware;
      useExperimentalGPUDriver = true;
    };

    # graphics = {
    #   enable = true;
    #   enable32Bit = true;
    # };

    bluetooth.enable = true;
    bluetooth.powerOnBoot = true;
  };

  # # User Config
  # users.users.evanreichard = {
  #   isNormalUser = true;
  #   home = "/home/evanreichard";
  #   extraGroups = [ "wheel" "networkmanager" "video" ];
  #   shell = pkgs.bash;
  # };

  # # Home Manager Config
  # home-manager = {
  #   useGlobalPkgs = true;
  #   useUserPackages = true;
  #   users.evanreichard = import ../home-manager/home.nix;
  # };

  # HyprLand Config
  programs.hyprland.enable = true;
  # environment.sessionVariables.NIXOS_OZONE_WL = "1";
  # environment.sessionVariables.WLR_NO_HARDWARE_CURSORS = "1";

  # System Packages
  environment.systemPackages = with pkgs; [
    ghostty
    firefox
    htop
    tmux
    vim
    wget

    # hyprlock
    # hypridle
  ];
}
